@@ -7,16 +7,16 @@
     if(plotoptions@residplot)
          plotFLIMresid(multimodel, multitheta, plotoptions) 
     if(plotoptions@noFLIMsummary) return()
- for(i in 1:length(m)) {
-    k <- t[[i]]@kinpar
-    model <- m[[i]]
-    get(getOption("device"))()   
-    par(plotoptions@paropt)
-    par(mgp = c(2, 1, 0), mar=c(3,3,3,2), oma = c(1,0,4,0), cex.main=.95,
+    for(i in 1:length(m)) {
+      k <- t[[i]]@kinpar
+      model <- m[[i]]
+      get(getOption("device"))()
+      par(plotoptions@paropt)
+      par(mgp = c(2, 1, 0), mar=c(3,3,3,2), oma = c(1,0,4,0), cex.main=.95,
 	mfrow=c(plotoptions@summaryplotrow, plotoptions@summaryplotcol))
-    nt <- model@nt
-    nl <- model@nl
-    x <- model@x
+      nt <- model@nt
+      nl <- model@nl
+      x <- model@x
     x2 <- model@x2
     resultlist <- multimodel@fit@resultlist
     irfmu <- vector()
@@ -29,18 +29,18 @@
 	if( (m[[i]]@cohcol != 0)[1])
 		spec <- as.matrix(spectralist[[i]][,-m[[i]]@cohcol])
 
-	for (j in 1:dim(spec)[2]) {
+	for (j in 1:ncol(spec)) {
             hist(spec[, j], xlab = paste("tau=", signif(1/k[j], 5)), 
 	    main = paste("Comp.", j, "amplitude"))
         }
         
-        if (dim(spec)[2] > 1) {
-            sumspec <- rep(0, dim(spec)[1])
+        if (ncol(spec) > 1) {
+            sumspec <- rep(0, nrow(spec))
             sumAv <- matrix(0, length(k), model@nl)
-            for (j in 1:dim(spec)[2]) {
+            for (j in 1:ncol(spec)) {
                 sumspec <- sumspec + spec[, j]
             }
-            for (j in dim(spec)[2]:1) {
+            for (j in ncol(spec):1) {
                 sumAv[j, ] <- spec[,j]/sumspec
                 if (j != 1) 
                   hist(sumAv[j, ], xlab = paste("mean", signif(mean(spec[, 
@@ -52,7 +52,6 @@
     colvec <- gray(seq(from = 0, to = 1, length = 100))
     image.plot(model@inten, col = colvec, xlab = "", axes = FALSE, 
         ylab = "", main = "Intensity image")
-    require(gclus)
     tt <- (model@inten - min(model@inten))/max(model@inten - 
         min(model@inten))
     colmat <- gray(tt)
@@ -60,42 +59,42 @@
     dim(colmat) <- dim(model@inten)
     csave <- colmat
     colmat <- t(colmat)
-    for (j in 1:(dim(colmat)[2])) 
+    for (j in 1:(ncol(colmat))) 
 	colmat[, j] <- rev(colmat[, j])
     plotcolors(colmat, main = "Region of interest")
-    tracemat <- matrix(0, dim(model@inten)[1], dim(model@inten)[2])
+    tracemat <- matrix(0, nrow(model@inten), ncol(model@inten))
 
    
     ## find out the rows where the selected pixels begin and end
    c1 <- c2 <- TRUE 
-   for(j in 1:dim(csave)[2]) { 
+   for(j in 1:ncol(csave)) { 
 	 if(c1)
 	    if("#0000FF" %in% csave[,j]) {	
 	        colstart <- j
 		c1 <- FALSE 
             }
 	 if(c2)
-	    if("#0000FF" %in% csave[,dim(csave)[2]-(j-1)]) {	
-		colend <- dim(csave)[2]-(j-1) 
+	    if("#0000FF" %in% csave[,ncol(csave)-(j-1)]) {	
+		colend <- ncol(csave)-(j-1) 
 		c2 <- FALSE 
 	    }
    }
    c1 <- c2 <- TRUE 
-   for(j in 1:dim(csave)[1]) { 
+   for(j in 1:nrow(csave)) { 
 	  if(c1) 
 	      if("#0000FF" %in% csave[j,]) {	
 	          rowstart <- j
 		  c1 <- FALSE
 	      }
 	   if(c2)     
-	      if("#0000FF" %in% csave[dim(csave)[1]-(j-1),] ) {	
-	        rowend <- dim(csave)[1]-(j-1)
+	      if("#0000FF" %in% csave[nrow(csave)-(j-1),] ) {	
+	        rowend <- nrow(csave)-(j-1)
 	        c2 <- FALSE
 	      }
    }
 
    ## <tau> 
-    if (dim(spec)[2] > 1) {
+    if (ncol(spec) > 1) {
       
 	xmat <- matrix(nrow = length(k), ncol = model@nl)
         vecres <- vector()
@@ -115,7 +114,7 @@
         main = " < tau > ", zlim = zlim)
     }
 
-    if (dim(spec)[2] > 1) {
+    if (ncol(spec) > 1) {
         for (j in 1:length(k)) {
             resmat <- as.vector(tracemat)
             resmat[model@x2] <- sumAv[j, ]
@@ -189,10 +188,14 @@
       if(plotoptions@output == "pdf")
         pdev <- pdf 
       else  pdev <- postscript
-        dev.print(device = pdev, file = paste(plotoptions@makeps,
-	"dataset_", i, "_summary.", plotoptions@output, 
-	sep = ""))
+      dev.print(device = pdev, file = paste(plotoptions@makeps,
+	"dataset_", i, "_summary.", plotoptions@output, sep = ""))
     }
-  }
+    }
+      plotEstout <- plotEst(multimodel, plotoptions, tr=TRUE,addplot=FALSE)
+      writeEst(multimodel, multitheta, plotoptions, plotEstout)
+      displayEst(plotoptions)
+
+    
 
 }
